@@ -30,12 +30,15 @@ from .protocol_base import ChimeraProtBase
 
 
 class ChimeraProtRigidFit(ChimeraProtBase):
+    # """Protocol to perform rigid fit using Chimera.
+    #     Execute command *scipionwrite [model #n] [refmodel #p]
+    #     [saverefmodel 0|1]* from command line in order to transferm fitted
+    #     pdb to scipion. Default values are model=#0,
+    #     refmodel =#1 and saverefmodel 0 (false).
+    #     model refers to the pdb file. refmodel to a 3Dmap"""
     """Protocol to perform rigid fit using Chimera.
-        Execute command *scipionwrite [model #n] [refmodel #p]
-        [saverefmodel 0|1]* from command line in order to transferm fitted
-        pdb to scipion. Default values are model=#0,
-        refmodel =#1 and saverefmodel 0 (false).
-        model refers to the pdb file. refmodel to a 3Dmap"""
+            Execute command *scipionwrite #n [prefix stringAddedToFilename]
+            model refers to the pdb file"""
     _label = 'rigid fit'
 
     def _defineParams(self, form):
